@@ -1,3 +1,4 @@
+import warnings
 from datetime import timedelta
 from urllib.parse import urljoin, urlparse
 
@@ -207,9 +208,10 @@ class FormResponderMixin(object):
         return self.form_cls()
 
     def assign_template_vars(self, form):
+        title_var = flask.current_app.config.get('KEGAUTH_TEMPLATE_TITLE_VAR')
         self.assign('form', form)
         self.assign('form_action_text', self.page_title)
-        self.assign('page_title', self.page_title)
+        self.assign(title_var, self.page_title)
         self.assign('page_heading', self.page_title)
 
     def get(self, *args, **kwargs):
@@ -797,6 +799,10 @@ class OidcLoginViewResponder(LoginResponderMixin, ViewResponder):
     page_title = 'Log In'
     template_name = 'keg_auth/flash-messages-only.html'
 
+    def __init__(self, parent):
+        warnings.warn(OidcAuthenticator.usage_warning, PendingDeprecationWarning, 2)
+        super().__init__(parent)
+
     def get(self, *args, **kwargs):
         oidc = flask.current_app.auth_manager.oidc
         oidc_check = oidc.require_login(lambda: True)()
@@ -825,6 +831,10 @@ class OidcLoginViewResponder(LoginResponderMixin, ViewResponder):
 class OidcLogoutViewResponder(LogoutViewResponder):
     """ OIDC logout requires some extra leg-work, because token gets refreshed server-side"""
 
+    def __init__(self, parent):
+        warnings.warn(OidcAuthenticator.usage_warning, PendingDeprecationWarning, 2)
+        super().__init__(parent)
+
     def get(self):
         oidc = flask.current_app.auth_manager.oidc
         url_login = flask.url_for(flask.current_app.auth_manager.endpoint('login'))
@@ -876,8 +886,16 @@ class OidcAuthenticator(LoginAuthenticator):
         'login': OidcLoginViewResponder,
         'logout': OidcLogoutViewResponder,
     }
+    usage_warning = (
+        'flask-oidc formed the core of this authenticator but has not received much maintenance '
+        'in the last few years. At this time, the library is depending on deprecated/removed '
+        'items in other libraries (such as itsdangerous) and will need to be updated to be '
+        'reliably operational again.'
+    )
 
     def __init__(self, app):
+        warnings.warn(self.usage_warning, PendingDeprecationWarning, 2)
+
         from flask_oidc import OpenIDConnect
 
         oidc_settings = {
