@@ -130,6 +130,20 @@ class TestViews(object):
             nav_el = resp.pyquery('#navigation')
             assert nav_el('[href="#navgroup-auth"]').attr('aria-expanded') != 'true'
 
+    def test_navigation_group_class(self):
+        user = ents.User.testing_create(permissions=[self.perm_auth, self.perm1, self.perm2])
+        client = AuthTestApp(flask.current_app, user=user)
+        resp = client.get('/')
+        nav_el = resp.pyquery('#navigation')
+        assert nav_el('.group-header.my-group-class').text() == 'Sub-Menu'
+
+    def test_navigation_link_class(self):
+        user = ents.User.testing_create(permissions=[self.perm_auth, self.perm1, self.perm2])
+        client = AuthTestApp(flask.current_app, user=user)
+        resp = client.get('/')
+        nav_el = resp.pyquery('#navigation')
+        assert nav_el('.my-link-class').text() == 'Secret View'
+
     def test_navigation_icon(self):
         user = ents.User.testing_create(permissions=[self.perm_auth])
         client = AuthTestApp(flask.current_app, user=user)
@@ -669,7 +683,7 @@ class TestUserCrud(ViewTestBase):
         resp.form['email'] = 'foobar@baz.com'
         resp = resp.form.submit()
 
-        assert resp.pyquery('#reset_password').siblings('.help-block').text() == \
+        assert resp.pyquery('#reset_password').siblings('.invalid-feedback').text() == \
             'This field is required.'
         resp.form['reset_password'] = 'bleh'
         resp.form['confirm'] = 'bleh'
@@ -1374,6 +1388,7 @@ def oidc_auth_client(oidc_client, auth_user):
         yield oidc_client
 
 
+@pytest.mark.skip('flask-oidc is broken against latest itsdangerous')
 class TestOidcLogin:
     def test_authenticated(self, oidc_auth_client):
         resp = oidc_auth_client.get('/login', status=302)
@@ -1394,6 +1409,7 @@ class TestOidcLogin:
         assert 'oauth2/v1/authorize?' in resp.location
 
 
+@pytest.mark.skip('flask-oidc is broken against latest itsdangerous')
 class TestOidcLogout:
     def test_unauthenticated(self, oidc_client):
         resp = oidc_client.get('/logout', status=302)
